aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorcash <cash@36083f99-b078-4883-b0ff-0f9b5a30f544>2011-04-06 02:47:08 +0000
committercash <cash@36083f99-b078-4883-b0ff-0f9b5a30f544>2011-04-06 02:47:08 +0000
commit60832059f8f29761e7c7dc8457f6ff97e0e74a55 (patch)
treeb61a275e76d0be8c73ced3f1df6d734bfac41c3a
parente55ac32a5c56a3d3065dcb80b93f080efd02b1c0 (diff)
downloadelgg-60832059f8f29761e7c7dc8457f6ff97e0e74a55.tar.gz
elgg-60832059f8f29761e7c7dc8457f6ff97e0e74a55.tar.bz2
Refs #3108 frontend should be done and ready for review - admin area is next
git-svn-id: http://code.elgg.org/elgg/trunk@8946 36083f99-b078-4883-b0ff-0f9b5a30f544
-rw-r--r--_graphics/elgg_sprites.pngbin10729 -> 12876 bytes
-rw-r--r--engine/lib/views.php10
-rw-r--r--mod/bookmarks/start.php2
-rw-r--r--mod/bookmarks/views/default/object/bookmarks.php4
-rw-r--r--mod/messages/start.php2
-rw-r--r--views/default/css/elements/helpers.php8
-rw-r--r--views/default/css/elements/icons.php128
-rw-r--r--views/default/river/relationship/friend/create.php2
8 files changed, 100 insertions, 56 deletions
diff --git a/_graphics/elgg_sprites.png b/_graphics/elgg_sprites.png
index 93e5e31f7..97cfa611b 100644
--- a/_graphics/elgg_sprites.png
+++ b/_graphics/elgg_sprites.png
Binary files differ
diff --git a/mod/bookmarks/start.php b/mod/bookmarks/start.php
index 394c6c561..600293b5a 100644
--- a/mod/bookmarks/start.php
+++ b/mod/bookmarks/start.php
@@ -42,7 +42,7 @@ function bookmarks_init() {
elgg_register_menu_item('extras', array(
'name' => 'bookmark',
- 'text' => elgg_view_icon('bookmark'),
+ 'text' => elgg_view_icon('push-pin-alt'),
'href' => "bookmarks/add/$user_guid?address=$address",
'title' => elgg_echo('bookmarks:this'),
'rel' => 'nofollow',
diff --git a/mod/bookmarks/views/default/object/bookmarks.php b/mod/bookmarks/views/default/object/bookmarks.php
index 5605e7277..97c68914e 100644
--- a/mod/bookmarks/views/default/object/bookmarks.php
+++ b/mod/bookmarks/views/default/object/bookmarks.php
@@ -68,7 +68,7 @@ if ($full && !elgg_in_context('gallery')) {
$list_body = elgg_view('page/components/summary', $params);
$bookmark_info = elgg_view_image_block($owner_icon, $list_body);
- $bookmark_icon = elgg_view_icon('bookmark');
+ $bookmark_icon = elgg_view_icon('push-pin-alt');
echo <<<HTML
$header
$bookmark_info
@@ -108,7 +108,7 @@ HTML;
'text' => $display_text
)));
- $content = elgg_view_icon('bookmark') . "$link{$excerpt}";
+ $content = elgg_view_icon('push-pin-alt') . "$link{$excerpt}";
$params = array(
'entity' => $bookmark,
diff --git a/mod/messages/start.php b/mod/messages/start.php
index fd8b7712d..14fc4c3bb 100644
--- a/mod/messages/start.php
+++ b/mod/messages/start.php
@@ -30,7 +30,7 @@ function messages_init() {
'context' => 'messages',
));
- $class = "elgg-icon messages-icon";
+ $class = "elgg-icon elgg-icon-mail";
$text = "<span class='$class'></span>";
// get unread messages
diff --git a/views/default/css/elements/helpers.php b/views/default/css/elements/helpers.php
index ac13c0efc..3ad9f8287 100644
--- a/views/default/css/elements/helpers.php
+++ b/views/default/css/elements/helpers.php
@@ -33,6 +33,14 @@
text-align: center;
}
+.float {
+ float: left;
+}
+
+.float-alt {
+ float: right;
+}
+
.right {
float: right;
}
diff --git a/views/default/css/elements/icons.php b/views/default/css/elements/icons.php
index bae905b40..27005acf7 100644
--- a/views/default/css/elements/icons.php
+++ b/views/default/css/elements/icons.php
@@ -19,148 +19,180 @@
display: inline-block;
margin: 0 2px;
}
-.elgg-icon-calendar {
+.elgg-icon-arrow-left {
background-position: 0 -0px;
}
-.elgg-icon-checkmark {
+.elgg-icon-arrow-right {
background-position: 0 -18px;
}
-.elgg-icon-cursor-drag-arrow {
+.elgg-icon-arrow-two-head {
background-position: 0 -36px;
}
-.elgg-icon-delete-alt:hover {
+.elgg-icon-calendar {
background-position: 0 -54px;
}
-.elgg-icon-delete-alt {
+.elgg-icon-checkmark {
background-position: 0 -72px;
}
-.elgg-icon-delete:hover {
+.elgg-icon-cursor-drag-arrow {
background-position: 0 -90px;
}
-.elgg-icon-delete {
+.elgg-icon-delete-alt:hover {
background-position: 0 -108px;
}
-.elgg-icon-download {
+.elgg-icon-delete-alt {
background-position: 0 -126px;
}
-.elgg-icon-facebook {
+.elgg-icon-delete:hover {
background-position: 0 -144px;
}
-.elgg-icon-home {
+.elgg-icon-delete {
background-position: 0 -162px;
}
-.elgg-icon-mail-empty {
+.elgg-icon-download {
background-position: 0 -180px;
}
-.elgg-icon-mail-full {
+.elgg-icon-facebook {
background-position: 0 -198px;
}
-.elgg-icon-print {
+.elgg-icon-home {
background-position: 0 -216px;
}
-.elgg-icon-push-pin {
+.elgg-icon-hover-menu:hover {
background-position: 0 -234px;
}
-.elgg-icon-redo {
+.elgg-icon-hover-menu {
background-position: 0 -252px;
}
-.elgg-icon-refresh {
+.elgg-icon-link {
background-position: 0 -270px;
}
-.elgg-icon-round-arrow-left {
+.elgg-icon-mail-alt:hover {
background-position: 0 -288px;
}
-.elgg-icon-round-arrow-right {
+.elgg-icon-mail-alt {
background-position: 0 -306px;
}
-.elgg-icon-round-checkmark {
+.elgg-icon-mail:hover {
background-position: 0 -324px;
}
-.elgg-icon-round-minus {
+.elgg-icon-mail {
background-position: 0 -342px;
}
-.elgg-icon-round-plus {
+.elgg-icon-print {
background-position: 0 -360px;
}
-.elgg-icon-rss {
+.elgg-icon-push-pin-alt {
background-position: 0 -378px;
}
-.elgg-icon-search {
+.elgg-icon-push-pin {
background-position: 0 -396px;
}
-.elgg-icon-settings-alt:hover {
+.elgg-icon-redo {
background-position: 0 -414px;
}
-.elgg-icon-settings-alt {
+.elgg-icon-refresh {
background-position: 0 -432px;
}
-.elgg-icon-settings {
+.elgg-icon-round-arrow-left {
background-position: 0 -450px;
}
-.elgg-icon-shop-cart {
+.elgg-icon-round-arrow-right {
background-position: 0 -468px;
}
-.elgg-icon-speech-bubble-alt:hover {
+.elgg-icon-round-checkmark {
background-position: 0 -486px;
}
-.elgg-icon-speech-bubble-alt {
+.elgg-icon-round-minus {
background-position: 0 -504px;
}
-.elgg-icon-speech-bubble:hover {
+.elgg-icon-round-plus {
background-position: 0 -522px;
}
-.elgg-icon-speech-bubble {
+.elgg-icon-rss {
background-position: 0 -540px;
}
-.elgg-icon-star-fav-empty {
+.elgg-icon-search-focus {
background-position: 0 -558px;
}
-.elgg-icon-star-fav {
+.elgg-icon-search {
background-position: 0 -576px;
}
-.elgg-icon-tag {
+.elgg-icon-settings-alt:hover {
background-position: 0 -594px;
}
-.elgg-icon-thumbs-down-alt:hover {
+.elgg-icon-settings-alt {
background-position: 0 -612px;
}
-.elgg-icon-thumbs-down-alt {
+.elgg-icon-settings {
background-position: 0 -630px;
}
-.elgg-icon-thumbs-down {
+.elgg-icon-shop-cart {
background-position: 0 -648px;
}
-.elgg-icon-thumbs-up-alt:hover {
+.elgg-icon-speech-bubble-alt:hover {
background-position: 0 -666px;
}
-.elgg-icon-thumbs-up-alt,
-.elgg-icon-thumbs-up:hover {
+.elgg-icon-speech-bubble-alt {
background-position: 0 -684px;
}
-.elgg-icon-thumbs-up {
+.elgg-icon-speech-bubble:hover {
background-position: 0 -702px;
}
-.elgg-icon-trash {
+.elgg-icon-speech-bubble {
background-position: 0 -720px;
}
-.elgg-icon-twitter {
+.elgg-icon-star-empty {
background-position: 0 -738px;
}
-.elgg-icon-undo {
+.elgg-icon-star {
background-position: 0 -756px;
}
-.elgg-icon-user:hover {
+.elgg-icon-tag {
background-position: 0 -774px;
}
-.elgg-icon-user {
+.elgg-icon-thumbs-down-alt:hover {
background-position: 0 -792px;
}
-.elgg-icon-users:hover {
+.elgg-icon-thumbs-down:hover,
+.elgg-icon-thumbs-down-alt {
background-position: 0 -810px;
}
-.elgg-icon-users {
+.elgg-icon-thumbs-down {
background-position: 0 -828px;
}
+.elgg-icon-thumbs-up-alt:hover {
+ background-position: 0 -846px;
+}
+.elgg-icon-thumbs-up:hover,
+.elgg-icon-thumbs-up-alt {
+ background-position: 0 -864px;
+}
+.elgg-icon-thumbs-up {
+ background-position: 0 -882px;
+}
+.elgg-icon-trash {
+ background-position: 0 -900px;
+}
+.elgg-icon-twitter {
+ background-position: 0 -918px;
+}
+.elgg-icon-undo {
+ background-position: 0 -936px;
+}
+.elgg-icon-user:hover {
+ background-position: 0 -954px;
+}
+.elgg-icon-user {
+ background-position: 0 -972px;
+}
+.elgg-icon-users:hover {
+ background-position: 0 -990px;
+}
+.elgg-icon-users {
+ background-position: 0 -1008px;
+}
+
.elgg-avatar > .elgg-icon-hover-menu {
display: none;
diff --git a/views/default/river/relationship/friend/create.php b/views/default/river/relationship/friend/create.php
index 4fbd7b01a..14dab4451 100644
--- a/views/default/river/relationship/friend/create.php
+++ b/views/default/river/relationship/friend/create.php
@@ -17,6 +17,6 @@ echo elgg_echo("friends:river:add", array($object_link));
echo '<div class="elgg-river-content clearfix">';
echo $subject_icon;
-echo elgg_view_icon('following');
+echo elgg_view_icon('arrow-right', true);
echo $object_icon;
echo '</div>';
diff --git a/engine/lib/views.php b/engine/lib/views.php
index 553c327a0..e2cf6b5c3 100644
--- a/engine/lib/views.php
+++ b/engine/lib/views.php
@@ -1278,12 +1278,16 @@ function elgg_view_list_item($item, array $vars = array()) {
*
* Shorthand for <span class="elgg-icon elgg-icon-$name"></span>
*
* @param string $name The specific icon to display
*
* @return string The html for displaying an icon
*/
-function elgg_view_icon($name) {
- return "<span class=\"elgg-icon elgg-icon-$name\"></span>";
+function elgg_view_icon($name, $float = false) {
+ if ($float) {
+ $float = 'float';
+ }
+ return "<span class=\"elgg-icon elgg-icon-$name $float\"></span>";
}
/**
@@ -1278,12 +1278,16 @@ function elgg_view_list_item($item, array $vars = array()) {
* Shorthand for <span class="elgg-icon elgg-icon-$name"></span>
*
- * @param string $name The specific icon to display
+ * @param string $name The specific icon to display
+ * @param bool $float Whether to float the icon
*
* @return string The html for displaying an icon